import CastorcitoForm from './components/Form/castorcito_form.js';

const fields = drupalSettings.field_components;
Object.entries(fields).forEach(([key, field]) => {
  const app = Vue.createApp({
    components: {
      'castorcito-form': CastorcitoForm
    },
    data() {
      const component_id = field.components[0];
      return {
        components: drupalSettings.components,
        formData: {
          componentModel: {},
          fieldsSettings: drupalSettings.components_fields_settings[component_id],
          fieldNameDrupal: key,
          componentId: component_id,
          fieldDeltaDrupal: 0
        }
      };
    },
    mounted() {
      const textareas = document.querySelectorAll(`textarea[name^="${key}["]`);
      textareas.forEach((textarea) => {
        const componentId = this.formData.componentId;
        const component = drupalSettings.components?.[componentId];
        if (!component) {
          console.warn(`Component ID ${componentId} was not found in drupalSettings.`);
          return;
        }

        this.formData.componentModel = structuredClone(component);
        this.fieldDeltaDrupal = textarea.getAttribute('target-weight');
        if (textarea.value) {
          try {
            let textareaJson = JSON.parse(textarea.value);
            const fieldsSettings = JSON.parse(JSON.stringify(this.formData.fieldsSettings));
            textareaJson = this.orderFields(textareaJson, fieldsSettings);
            this.formData.componentModel = textareaJson;
          } catch (error) {
            console.error(`Error parsing JSON in textarea: ${error.message}`);
          }
        }
      });
    },
    methods: {
      orderFields(component, fieldsSettings) {
        if (!fieldsSettings?.order_fields || !component?.fields) {
          return component;
        }

        const orderedFields = {};
        fieldsSettings.order_fields.forEach((key) => {
          const field = component.fields[key];
          if (field) {
            if (field.type === 'container' && Array.isArray(field.items)) {
              field.items = field.items.map((item) => {
                const itemSettings = drupalSettings.components_fields_settings[item.type];
                return this.orderFields(item, itemSettings);
              });
            }

            orderedFields[key] = field;
          }
        });

        component.fields = orderedFields;
        return component;
      }
    }
  });

  app.mount('#app_' + key);
});
